#include "mainwindow.h"

#include <QSqlDatabase>
#include <QSqlQuery>
#include <QSqlError>

#include <QStringListModel>
#include <QMessageBox>
#include <QInputDialog>


MainWindow::MainWindow(QWidget *parent)
	: QMainWindow(parent)
{
	setupUi(this);

	connect(actionDrivers_info, SIGNAL(triggered()),
			this, SLOT(driversInfo()));
	connect(action_Exit, SIGNAL(triggered()),
			this, SLOT(close()));

	connect(beginButton, SIGNAL(clicked()),
			this, SLOT(beginButton_clicked()));
	connect(commitButton, SIGNAL(clicked()),
			this, SLOT(commitButton_clicked()));
	connect(rollbackButton, SIGNAL(clicked()),
			this, SLOT(rollbackButton_clicked()));
	connect(correctCommandButton, SIGNAL(clicked()),
			this, SLOT(correctCommandButton_clicked()));
	connect(wrongCommandButton, SIGNAL(clicked()),
			this, SLOT(wrongCommandButton_clicked()));

	QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE");
	db.setDatabaseName(":memory:");
	db.open();

	executeStatement("create table foo"
					 "(id integer primary key autoincrement,"
					 "bar1 text, bar2 number);"
					 );

	correctCommandButton_clicked();
}

MainWindow::~MainWindow()
{
}

// Metoda vykona SQL prikaz a zobrazi informace
// s vysledkem operace.
void MainWindow::executeStatement(const QString & statement,
								  const QList<QVariant> & params)
{
	QSqlQuery q(QSqlDatabase::database());

    // SQL je predpripraveno, ale jeste nevykonano
	q.prepare(statement);

	textBrowser->append("EXEC: " + q.lastQuery());

    // automaticky "nabinduji" hodnoty do SQL prikazu
	foreach (QVariant i, params)
	{
		textBrowser->append("BIND: " + i.toString());
		q.addBindValue(i);
	}

    // a konecne SQL vykonam
	if (q.exec())
	{
		textBrowser->append("OK\n");
		return;
	}

    // do log widgetu se zapise vysledek operace
	textBrowser->append("ERR:");
	textBrowser->append("   DB text: " + q.lastError().databaseText());
	textBrowser->append("   Drv text: " + q.lastError().driverText());
	textBrowser->append("\n");
}

void MainWindow::driversInfo()
{
	QInputDialog::getItem(this, tr("Drivers"),
						  tr("Available DB Drivers:"),
						  QSqlDatabase::drivers(),
						  0, false);
}

void MainWindow::beginButton_clicked()
{
	executeStatement("BEGIN;");
}

void MainWindow::commitButton_clicked()
{
	executeStatement("COMMIT;");
}

void MainWindow::rollbackButton_clicked()
{
	executeStatement("ROLLBACK;");
}

// INSERT by se mel povest
void MainWindow::correctCommandButton_clicked()
{
	QList<QVariant> l;
	l << "text" << qrand();
	executeStatement("insert into foo (bar1, bar2) values (:1, :2);", l);
}

// INSERT spadne na duplicitni PK
void MainWindow::wrongCommandButton_clicked()
{
	QList<QVariant> l;
	l << 1 << "text" << qrand();
	executeStatement("insert into foo (id, bar1, bar2) values (:1, :2, :3);", l);
}
