#include "insertpetdialog.h"

#include <QSqlRelationalTableModel>
#include <QSqlRelationalDelegate>
#include <QSqlError>
#include <QFileDialog>
#include <QMessageBox>


InsertPetDialog::InsertPetDialog(QSqlRelationalTableModel * model,
								 QWidget * parent)
	: QDialog(parent),
	m_model(model)
{
	setupUi(this);

	tableView->setModel(m_model);
	tableView->hideColumn(0);

	tableView->setItemDelegateForColumn(5, new QSqlRelationalDelegate(tableView));
	tableView->setItemDelegateForColumn(3, new PictureDelegate(tableView));

	connect(newRowButton, SIGNAL(clicked()),
			this, SLOT(newRowButton_clicked()));
}

void InsertPetDialog::accept()
{
	if (!m_model->submitAll())
	{
		QMessageBox::warning(this, tr("Commit error"),
							 m_model->lastError().databaseText());
		return;
	}
	QDialog::accept();
}

void InsertPetDialog::newRowButton_clicked()
{
	m_model->insertRows(m_model->rowCount(), 1);
	tableView->scrollToBottom();
}


////////////////////////////////////////////////////

PictureButton::PictureButton(QWidget * parent)
	: QPushButton(tr("Change Picture"), parent)
{
	connect(this, SIGNAL(clicked()),
			this, SLOT(loadImage()));
}

QVariant PictureButton::rawPicture()
{
	return m_data;
}

void PictureButton::loadImage()
{
	 QString fileName = QFileDialog::getOpenFileName(this,
													 tr("Open File"),
													"/home",
													tr("Images (*.png *.jpg)"));
	 if (fileName.isNull())
		 return;

	 QFile f(fileName);
	 if (f.open(QIODevice::ReadOnly))
		 m_data = QVariant(f.readAll());
}


////////////////////////////////////////////////////

PictureDelegate::PictureDelegate(QObject * parent)
	: QItemDelegate(parent)
{
}

QWidget *PictureDelegate::createEditor(QWidget *parent,
								   const QStyleOptionViewItem &/* option */,
								   const QModelIndex &/* index */) const
{
	PictureButton *editor = new PictureButton(parent);
	editor->setFocus();
	editor->setFocusPolicy(Qt::StrongFocus);
	return editor;
}

void PictureDelegate::setEditorData(QWidget *editor,
								const QModelIndex &index) const
{
}

void PictureDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
							   const QModelIndex &index) const
{
	PictureButton *ed = static_cast<PictureButton*>(editor);
	model->setData(index, ed->rawPicture(), Qt::EditRole);
}

void PictureDelegate::updateEditorGeometry(QWidget *editor,
									   const QStyleOptionViewItem &option,
									   const QModelIndex &/* index */) const
{
	editor->setGeometry(option.rect);
}
