#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "ownerdialog.h"
#include "insertpetdialog.h"

#include <QSqlRelationalTableModel>
#include <QSqlError>
#include <QSqlRecord>
#include <QMessageBox>


MainWindow::MainWindow(QWidget *parent)
	: QMainWindow(parent),
	m_mainModel(0)
{
	setupUi(this);

	QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE");
	db.setDatabaseName("../zoo.db");
	if (!db.open())
	{
		QMessageBox::warning(this, tr("Connection Error"), tr("Cannot open DB file"));
		return;
	}

	m_mainModel = new QSqlRelationalTableModel(this);
	m_mainModel->setEditStrategy(QSqlTableModel::OnManualSubmit);

	tableView->setModel(m_mainModel);

	m_mainModel->setTable("pets");
	m_mainModel->setRelation(5, QSqlRelation("owners", "id", "nickname"));
	if (!m_mainModel->select())
	{
		QMessageBox::warning(this, tr("Select Error"),
							 m_mainModel->lastError().databaseText());
		return;
	}

	tableView->hideColumn(0);
	tableView->hideColumn(2);
	tableView->hideColumn(3);
	tableView->hideColumn(4);

	connect(tableView->selectionModel(),
			SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)),
			this,
			SLOT(tableView_selectionChanged(const QItemSelection &, const QItemSelection &)));
	connect(action_List_Owners, SIGNAL(triggered()),
			this, SLOT(listOwners()));
	connect(actionAdd_New, SIGNAL(triggered()),
			this, SLOT(addNewPet()));
}

MainWindow::~MainWindow()
{
}

void MainWindow::tableView_selectionChanged(const QItemSelection &,
											const QItemSelection &)
{
	QPixmap pm;
	int row = tableView->currentIndex().row();
	QSqlRecord r(m_mainModel->record(row));

	nameEdit->setText(r.value("name").toString());
	breedEdit->setText(r.value("breed").toString());
	descriptionEdit->setPlainText(r.value("description").toString());

	pm.loadFromData(r.value("photo").toByteArray());
	QSize sz(imageLabel->width()-3, imageLabel->height()-3);
	imageLabel->setPixmap(pm.scaled(sz, Qt::KeepAspectRatio, Qt::SmoothTransformation));
}

void MainWindow::listOwners()
{
	OwnerDialog d(this);
	d.exec();
}

void MainWindow::addNewPet()
{
	m_mainModel->revertAll();
	InsertPetDialog d(m_mainModel, this);
	d.exec();
}
